# Django REST Framework Magic

![Python Testing](https://github.com/dstarner/drf-magic/workflows/Python%20Testing/badge.svg)

Django REST Framework Magic (DRF Magic) is a Django application that builds off our all of my
personal best practices of boiler-plates of working with a RESTful Django application. It makes a
fair amount of subjective coding decisions, but I hope that others see the benefit and
ease-of-development that they provide.

Read the Documentation: <https://drf-magic.readthedocs.io/en/latest/>